#!/usr/bin/env python
# coding: utf-8

# This example uses icons taken from the Visual Studio 2022 Image Library. To download that library or other versions, go to:
# 
# https://www.microsoft.com/en-us/download/details.aspx?id=35825
# 

# In[3]:


import tkinter as tk
from tkinter.filedialog import asksaveasfile
from PIL import Image, ImageTk
import math

# Layout constants.
MARGIN = 5
WINDOW_WID = 400
WINDOW_HGT = 300

class MenuApp:
    # Create and manage the tkinter interface.
    def __init__(self):
        # Make the main interface.
        self.window = tk.Tk()
        self.window.title('Menus')
        self.window.protocol('WM_DELETE_WINDOW', self.kill_callback)
        self.window.geometry(f'{WINDOW_WID}x{WINDOW_HGT}')

        # Build the menus.
        self.build_menus()

        # Build the rest of the UI here...

        # Display the window.
        self.window.focus_force()
        self.window.mainloop()

    def build_menus(self):
        '''Build the menu bar.'''
        menu_bar = tk.Menu(self.window)
        self.window.config(menu=menu_bar)

        self.build_file_menu(menu_bar)
        self.build_edit_menu(menu_bar)
        self.build_tools_menu(menu_bar)
        self.build_help_menu(menu_bar)

    def build_file_menu(self, menu_bar):
        '''Build the File menu.'''
        file_menu = tk.Menu(menu_bar, tearoff=False)
        menu_bar.add_cascade(label='File', menu=file_menu)

        # Note: You must save the photo image in a persistent
        # variable so tkinter can redraw it when needed.

        # Note: You need to include the compound parameter
        # if you want to use both images and text. That value
        # tells where to put the image relative to the text.

        # New
        self.new_photo_image = ImageTk.PhotoImage(file='new.png')        
        file_menu.add_command(label='New', accelerator='Ctrl+N', compound='left',
            command=self.mnu_new, image=self.new_photo_image)
        self.window.bind('<Control-n>', lambda event: self.mnu_new())

        # Open
        self.open_photo_image = ImageTk.PhotoImage(file='open.png')
        file_menu.add_command(label='Open...', accelerator='Ctrl+O', compound='left',
            command=self.mnu_open, image=self.open_photo_image)
        self.window.bind('<Control-o>', lambda event: self.mnu_open())

        file_menu.add_separator()

        # Save
        self.save_photo_image = ImageTk.PhotoImage(file='save.png')
        file_menu.add_command(label='Save', accelerator='Ctrl+S', compound='left',
            command=self.mnu_save, image=self.save_photo_image)
        self.window.bind('<Control-s>', lambda event: self.mnu_save())

        # Note: If you don't include an image, the menu item doesn't
        # quite line up with items that do have an image. You can fix
        # it by including a blank image.

        # Save As
        self.save_as_photo_image = ImageTk.PhotoImage(file='save_as.png')
        file_menu.add_command(label='Save As...', compound='left',
            command=self.mnu_save_as, image=self.save_as_photo_image)

        file_menu.add_separator()

        # Print
        self.print_photo_image = ImageTk.PhotoImage(file='print.png')
        file_menu.add_command(label='Print...', accelerator='Ctrl+P', compound='left',
            command=self.mnu_print, image=self.print_photo_image)
        self.window.bind('<Control-p>', lambda event: self.mnu_print())

        # Print Preview
        self.print_preview_photo_image = ImageTk.PhotoImage(file='print_preview.png')
        file_menu.add_command(label='Print Preview...', compound='left',
            command=self.mnu_print_preview, image=self.print_preview_photo_image)

        file_menu.add_separator()

        # Exit
        self.exit_photo_image = ImageTk.PhotoImage(file='exit.png')
        file_menu.add_command(label='Exit', compound='left',
            command=self.mnu_exit, image=self.exit_photo_image)

    def mnu_new(self):
        print('New')
    def mnu_open(self):
        print('Open')
    def mnu_save(self):
        print('Save')
    def mnu_save_as(self):
        print('Save As')
    def mnu_print(self):
        print('Print')
    def mnu_print_preview(self):
        print('Print Preview')
    def mnu_exit(self):
        print('Exit')
        self.kill_callback()

    def build_edit_menu(self, menu_bar):
        '''Build the Edit menu.'''
        edit_menu = tk.Menu(menu_bar, tearoff=False)
        menu_bar.add_cascade(label='Edit', menu=edit_menu)

        # Undo
        self.undo_photo_image = ImageTk.PhotoImage(file='undo.png')
        edit_menu.add_command(label='Undo', accelerator='Ctrl+Z', compound='left',
            command=self.mnu_undo, image=self.undo_photo_image)
        self.window.bind('<Control-z>', lambda event: self.mnu_undo())

        # Redo
        self.redo_photo_image = ImageTk.PhotoImage(file='redo.png')
        edit_menu.add_command(label='Redo', accelerator='Ctrl+Y', compound='left',
            command=self.mnu_redo, image=self.redo_photo_image)
        self.window.bind('<Control-y>', lambda event: self.mnu_redo())

        edit_menu.add_separator()

        # Cut
        self.cut_photo_image = ImageTk.PhotoImage(file='cut.png')
        edit_menu.add_command(label='Cut', accelerator='Ctrl+X', compound='left',
            command=self.mnu_cut, image=self.cut_photo_image)
        self.window.bind('<Control-x>', lambda event: self.mnu_cut())

        # Copy
        self.copy_photo_image = ImageTk.PhotoImage(file='copy.png')
        edit_menu.add_command(label='Copy', accelerator='Ctrl+C', compound='left',
            command=self.mnu_copy, image=self.copy_photo_image)
        self.window.bind('<Control-c>', lambda event: self.mnu_copy())

        # Paste
        self.paste_photo_image = ImageTk.PhotoImage(file='paste.png')
        edit_menu.add_command(label='Paste', accelerator='Ctrl+V', compound='left',
            command=self.mnu_paste, image=self.paste_photo_image)
        self.window.bind('<Control-v>', lambda event: self.mnu_paste())

        # Delete
        self.delete_photo_image = ImageTk.PhotoImage(file='delete.png')
        edit_menu.add_command(label='Delete', accelerator='Ctrl+Backspace', compound='left',
            command=self.mnu_delete, image=self.delete_photo_image)
        self.window.bind('<Control-BackSpace>', lambda event: self.mnu_delete())

        edit_menu.add_separator()

        # Select All
        self.select_all_photo_image = ImageTk.PhotoImage(file='select_all.png')
        edit_menu.add_command(label='Select_all', accelerator='Ctrl+A', compound='left',
            command=self.mnu_select_all, image=self.select_all_photo_image)
        self.window.bind('<Control-a>', lambda event: self.mnu_select_all())

    def mnu_undo(self):
        print('Undo')
    def mnu_redo(self):
        print('Redo')
    def mnu_cut(self):
        print('Cut')
    def mnu_copy(self):
        print('Copy')
    def mnu_paste(self):
        print('Paste')
    def mnu_delete(self):
        print('Delete')
    def mnu_select_all(self):
        print('Select All')

    def build_tools_menu(self, menu_bar):
        '''Build the Tools menu.'''
        tools_menu = tk.Menu(menu_bar, tearoff=False)
        menu_bar.add_cascade(label='Tools', menu=tools_menu)

        # Customize
        self.customize_photo_image = ImageTk.PhotoImage(file='customize.png')
        tools_menu.add_command(label='Customize', compound='left',
            command=self.mnu_customize, image=self.customize_photo_image)

        # Settings
        self.settings_photo_image = ImageTk.PhotoImage(file='settings.png')
        tools_menu.add_command(label='Settings', compound='left',
            command=self.mnu_settings, image=self.settings_photo_image)

    def mnu_customize(self):
        print('Customize')
    def mnu_settings(self):
        print('Settings')

    def build_help_menu(self, menu_bar):
        '''Build the Help menu.'''
        help_menu = tk.Menu(menu_bar, tearoff=False)
        menu_bar.add_cascade(label='Help', menu=help_menu)

        # Contents
        self.contents_photo_image = ImageTk.PhotoImage(file='contents.png')
        help_menu.add_command(label='Contents', compound='left',
            command=self.mnu_contents, image=self.contents_photo_image)

        # Index
        self.index_photo_image = ImageTk.PhotoImage(file='index.png')
        help_menu.add_command(label='Index', compound='left',
            command=self.mnu_index, image=self.index_photo_image)

        # Search
        self.search_photo_image = ImageTk.PhotoImage(file='search.png')
        help_menu.add_command(label='Search', compound='left',
            command=self.mnu_search, image=self.search_photo_image)

        # About
        self.about_photo_image = ImageTk.PhotoImage(file='about.png')
        help_menu.add_command(label='About...', compound='left',
            command=self.mnu_about, image=self.about_photo_image)

    def mnu_contents(self):
        print('Contents')
    def mnu_index(self):
        print('Index')
    def mnu_search(self):
        print('Search')
    def mnu_about(self):
        print('About')

    def kill_callback(self):
        self.window.destroy()


# In[4]:


MenuApp()
print('Done')


# In[ ]:




